==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lt-LT/localizations.php <==
<?php

return [

    'select_language' => 'Pasirinkite kalbą',
    'languages' => [
        'en-US'=> 'Anglų, JAV',
        'en-GB'=> 'Anglų, Jungtinė Karalystė',
        'am-ET' => 'Amharų',
        'af-ZA'=> 'Afrikanų',
        'ar-SA'=> 'Arabų',
        'bg-BG'=> 'Bulgarų',
        'zh-CN'=> 'Kinų (supaprastinta)',
        'zh-TW'=> 'Kinų (tradicinė)',
        'ca-ES' => 'Katalonų',
        'hr-HR'=> 'Kroatų',
        'cs-CZ'=> 'Čekų',
        'da-DK'=> 'Danų',
        'nl-NL'=> 'Olandų',
        'en-ID'=> 'Anglų, Indonezija',
        'et-EE'=> 'Estų',
        'fil-PH'=> 'Filipiniečių',
        'fi-FI'=> 'Suomių',
        'fr-FR'=> 'Prancūzų',
        'de-DE'=> 'Vokiečių',
        'de-if'=> 'Vokiečių (neformali)',
        'el-GR'=> 'Graikų',
        'he-IL'=> 'Hebrajų',
        'hu-HU'=> 'Vengrų',
        'is-IS' => 'Islandų',
        'id-ID'=> 'Indoneziečių',
        'ga-IE'=> 'Airių',
        'it-IT'=> 'Italų',
        'ja-JP'=> 'Japonų',
        'km-KH'=>'Khmerų',
        'ko-KR'=> 'Korėjiečių',
        'lt-LT'=>'Lietuvių',
        'lv-LV'=> 'Latvių',
        'mk-MK'=> 'Makedonų',
        'ms-MY'=> 'Malajų',
        'mi-NZ'=> 'Maorių',
        'mn-MN'=> 'Mongolų',
        'no-NO'=> 'Norvegų',
        'fa-IR'=> 'Persų',
        'pl-PL'=> 'Lenkų',
        'pt-PT'=> 'Portugalų',
        'pt-BR'=> 'Portugalų, brazilų',
        'ro-RO'=> 'Rumunų',
        'ru-RU'=> 'Rusų',
        'sr-CS' => 'Serbų (lotynų)',
        'sk-SK'=> 'Slovakų',
        'sl-SI'=> 'Slovėnų',
        'so-SO'=> 'Somalių',
        'es-ES'=> 'Ispanų',
        'es-CO'=> 'Ispanų, Kolumbija',
        'es-MX'=> 'Ispanų, Meksika',
        'es-VE'=> 'Ispanų, Venesuela',
        'sv-SE'=> 'Švedų',
        'tl-PH'=> 'Tagalogų',
        'ta-IN'=> 'Tamilų',
        'th-TH'=> 'Tailandiečių',
        'tr-TR'=> 'Turkų',
        'uk-UA'=> 'Ukrainiečių',
        'vi-VN'=> 'Vietnamiečių',
        'cy-GB'=> 'Valų',
        'zu-ZA'=> 'Zulų',
    ],

    'select_country' => 'Pasirinkite šalį',
    
    'countries' => [
        'AC'=>'Dangun Žengimo sala',
        'AD'=>'Andora',
        'AE'=>'Jungtiniai Arabų Emyratai',
        'AF'=>'Afganistanas',
        'AG'=>'Antigva ir Barbuda',
        'AI'=>'Angilija',
        'AL'=>'Albanija',
        'AM'=>'Armėnija',
        'AN'=>'Nyderlandų Antilai',
        'AO'=>'Angola',
        'AQ'=>'Antarktida',
        'AR'=>'Argentina',
        'AS'=>'Amerikos Samoa',
        'AT'=>'Austrija',
        'AU'=>'Australija',
        'AW'=>'Aruba',
        'AX'=>'Alandai',
        'AZ'=>'Azerbaidžanas',
        'BA'=>'Bosnija ir Hercogovina',
        'BB'=>'Barbadosas',
        'BE'=>'Belgija',
        'BD'=>'Bangladešas',
        'BF'=>'Burkina Fasas',
        'BG'=>'Bulgarija',
        'BH'=>'Bahreinas',
        'BI'=>'Burundis',
        'BJ'=>'Beninas',
        'BM'=>'Bermudai',
        'BN'=>'Brunėjaus Valstybės Darusalamas',
        'BO'=>'Bolivija',
        'BR'=>'Brazilija',
        'BS'=>'Bahamos',
        'BT'=>'Butanas',
        'BV'=>'Buvė sala',
        'BW'=>'Botsvana',
        'BY'=>'Baltarusija',
        'BZ'=>'Belizas',
        'CA'=>'Kanada',
        'CC'=>'Kokosų (Kilingo) salos',
        'CD'=>'Kongo Demokratinė Respublika',
        'CF'=>'Centrinės Afrikos Respublika',
        'CG'=>'Kongo Respublika',
        'CH'=>'Šveicarija',
        'CI'=>'Dramblio Kaulo Krantas',
        'CK'=>'Kuko salos',
        'CL'=>'Čilė',
        'CM'=>'Kamerūnas',
        'CN'=>'Kinija',
        'CO'=>'Kolumbija',
        'CR'=>'Kosta Rika',
        'CU'=>'Kuba',
        'CV'=>'Žaliasis Kyšulys',
        'CX'=>'Kalėdų sala',
        'CY'=>'Kipras',
        'CZ'=>'Čekija',
        'DE'=>'Vokietija',
        'DJ'=>'Džibutis',
        'DK'=>'Danija',
        'DM'=>'Dominika',
        'DO'=>'Dominikos Respublika',
        'DZ'=>'Alžyras',
        'EC'=>'Ekvadoras',
        'EE'=>'Estija',
        'EG'=>'Egiptas',
        'ER'=>'Eritrėja',
        'ES'=>'Ispanija',
        'ET'=>'Etiopija',
        'EU'=>'Europos Sąjunga',
        'FI'=>'Suomija',
        'FJ'=>'Fidžis',
        'FK'=>'Folklando (Malvinų) salos',
        'FM'=>'Mikronezijos Federacinės Valstijos',
        'FO'=>'Farerai',
        'FR'=>'Prancūzija',
        'GA'=>'Gabonas',
        'GD'=>'Grenada',
        'GE'=>'Sakartvelas',
        'GF'=>'Prancūzijos Gviana',
        'GG'=>'Gernsis',
        'GH'=>'Gana',
        'GI'=>'Gibraltaras',
        'GL'=>'Grenlandija',
        'GM'=>'Gambija',
        'GN'=>'Gvinėja',
        'GP'=>'Gvadelupa',
        'GQ'=>'Pusiaujo Gvinėja',
        'GR'=>'Graikija',
        'GS'=>'Pietų Džordžijos ir Pietų Sandvičo salos',
        'GT'=>'Gvatemala',
        'GU'=>'Guamas',
        'GW'=>'Bisau Gvinėja',
        'GY'=>'Gajana',
        'HK'=>'Honkongas',
        'HM'=>'Herdo ir Makdonaldo salos',
        'HN'=>'Hondūras',
        'HR'=>'Kroatija',
        'HT'=>'Haitis',
        'HU'=>'Vengrija',
        'ID'=>'Indonezija',
        'IE'=>'Airija',
        'IL'=>'Izraelis',
        'IM'=>'Meno sala',
        'IN'=>'Indija',
        'IO'=>'Indijos Vandenyno Britų Sritis',
        'IQ'=>'Irakas',
        'IR'=>'Iranas',
        'IS'=>'Islandija',
        'IT'=>'Italija',
        'JE'=>'Džersis',
        'JM'=>'Jamaika',
        'JO'=>'Jordanija',
        'JP'=>'Japonija',
        'KE'=>'Kenija',
        'KG'=>'Kirgizija',
        'KH'=>'Kambodža',
        'KI'=>'Kiribatis',
        'KM'=>'Komorai',
        'KN'=>'Sent Kitsas ir Nevis',
        'KR'=>'Korėja',
        'KW'=>'Kuveitas',
        'KY'=>'Kaimanų salos',
        'KZ'=>'Kazachstanas',
        'LA'=>'Laosas',
        'LB'=>'Libanas',
        'LC'=>'Sent Lusija',
        'LI'=>'Lichtenšteinas',
        'LK'=>'Šri Lanka',
        'LR'=>'Liberija',
        'LS'=>'Lesotas',
        'LT'=>'Lietuva',
        'LU'=>'Liuksemburgas',
        'LV'=>'Latvija',
        'LY'=>'Libija',
        'MA'=>'Marokas',
        'MC'=>'Monakas',
        'MD'=>'Moldova',
        'ME'=>'Juodkalnija',
        'MG'=>'Madagaskaras',
        'MH'=>'Maršalo salos',
        'MK'=>'Šiaurės Makedonija',
        'ML'=>'Malis',
        'MM'=>'Mianmaras',
        'MN'=>'Mongolija',
        'MO'=>'Makao',
        'MP'=>'Marianos Šiaurinės salos',
        'MQ'=>'Martinika',
        'MR'=>'Mauritanija',
        'MS'=>'Montseratas',
        'MT'=>'Malta',
        'MU'=>'Mauricijus',
        'MV'=>'Maldyvai',
        'MW'=>'Malavis',
        'MX'=>'Meksika',
        'MY'=>'Malaizija',
        'MZ'=>'Mozambikas',
        'NA'=>'Namibija',
        'NC'=>'Naujoji Kaledonija',
        'NE'=>'Nigeris',
        'NF'=>'Norfolko sala',
        'NG'=>'Nigerija',
        'NI'=>'Nikaragva',
        'NL'=>'Nyderlandai',
        'NO'=>'Norvegija',
        'NP'=>'Nepalas',
        'NR'=>'Nauru',
        'NU'=>'Niujė',
        'NZ'=>'Naujoji Zelandija',
        'OM'=>'Omanas',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Prancūzijos Polinezija',
        'PG'=>'Papua Naujoji Gvinėja',
        'PH'=>'Filipinai',
        'PK'=>'Pakistanas',
        'PL'=>'Lenkija',
        'PM'=>'Sen Pjeras ir Mikelonas',
        'PN'=>'Pitkerno salos',
        'PR'=>'Puerto Rikas',
        'PS'=>'Palestina',
        'PT'=>'Portugalija',
        'PW'=>'Palau',
        'PY'=>'Paragvajus',
        'QA'=>'Kataras',
        'RE'=>'Reunjonas',
        'RO'=>'Rumunija',
        'RS'=>'Serbija',
        'RU'=>'Rusija',
        'RW'=>'Ruanda',
        'SA'=>'Saudo Arabija',
        'UK'=>'Škotija',
        'SB'=>'Saliamono salos',
        'SC'=>'Seišeliai',
        'SS'=>'Pietų Sudanas',
        'SD'=>'Sudanas',
        'SE'=>'Švedija',
        'SG'=>'Singapūras',
        'SH'=>'Šv. Elenos sala',
        'SI'=>'Slovėnija',
        'SJ'=>'Svaldbardo ir Jan Majeno salos',
        'SK'=>'Slovakija',
        'SL'=>'Siera Leonė',
        'SM'=>'San Marinas',
        'SN'=>'Senegalas',
        'SO'=>'Somalis',
        'SR'=>'Surinamas',
        'ST'=>'San Tomė ir Prinsipė',
        'SU'=>'Sovietų Sąjunga',
        'SV'=>'Salvadoras',
        'SY'=>'Sirija',
        'SZ'=>'Svazilandas',
        'TC'=>'Terksas ir Kaikosas',
        'TD'=>'Čadas',
        'TF'=>'Prancūzijos Pietų Sritys',
        'TG'=>'Togas',
        'TH'=>'Tailandas',
        'TJ'=>'Tadžikija',
        'TK'=>'Tokelau',
        'TI'=>'Rytų Timoras',
        'TM'=>'Turkmėnija',
        'TN'=>'Tunisas',
        'TO'=>'Tonga',
        'TP'=>'Rytų Timoras (senas kodas)',
        'TR'=>'Turkija',
        'TT'=>'Trinidadas ir Tobagas',
        'TV'=>'Tuvalu',
        'TW'=>'Taivanas',
        'TZ'=>'Tanzanija',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Jungtinė Karalystė',
        'US'=>'Jungtinės Amerikos Valstijos',
        'UM'=>'Jungtinių Valstijų mažosios tolimosios salos',
        'UY'=>'Urugvajus',
        'UZ'=>'Uzbekistanas',
        'VA'=>'Vatikanas',
        'VC'=>'Sent Vinsentas ir Grenadinai',
        'VE'=>'Venesuela',
        'VG'=>'Mergelių salos (Didžioji Britanija)',
        'VI'=>'Mergelių salos (JAV)',
        'VN'=>'Vietnamas',
        'VU'=>'Vanuatu',
        'WF'=>'Voliso ir Futūnos salos',
        'WS'=>'Samoa',
        'YE'=>'Jemenas',
        'YT'=>'Majotas',
        'ZA'=>'Pietų Afrika',
        'ZM'=>'Zambija',
        'ZW'=>'Zimbabvė',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lt-LT/localizations.php <==
<?php

return [

    'select_language' => 'Pasirinkite kalbą',
    'languages' => [
        'en-US'=> 'Anglų, JAV',
        'en-GB'=> 'Anglų, Jungtinė Karalystė',
        'am-ET' => 'Amharų',
        'af-ZA'=> 'Afrikanų',
        'ar-SA'=> 'Arabų',
        'bg-BG'=> 'Bulgarų',
        'zh-CN'=> 'Kinų (supaprastinta)',
        'zh-TW'=> 'Kinų (tradicinė)',
        'ca-ES' => 'Katalonų',
        'hr-HR'=> 'Kroatų',
        'cs-CZ'=> 'Čekų',
        'da-DK'=> 'Danų',
        'nl-NL'=> 'Olandų',
        'en-ID'=> 'Anglų, Indonezija',
        'et-EE'=> 'Estų',
        'fil-PH'=> 'Filipiniečių',
        'fi-FI'=> 'Suomių',
        'fr-FR'=> 'Prancūzų',
        'de-DE'=> 'Vokiečių',
        'de-if'=> 'Vokiečių (neformali)',
        'el-GR'=> 'Graikų',
        'he-IL'=> 'Hebrajų',
        'hu-HU'=> 'Vengrų',
        'is-IS' => 'Islandų',
        'id-ID'=> 'Indoneziečių',
        'ga-IE'=> 'Airių',
        'it-IT'=> 'Italų',
        'ja-JP'=> 'Japonų',
        'km-KH'=>'Khmerų',
        'ko-KR'=> 'Korėjiečių',
        'lt-LT'=>'Lietuvių',
        'lv-LV'=> 'Latvių',
        'mk-MK'=> 'Makedonų',
        'ms-MY'=> 'Malajų',
        'mi-NZ'=> 'Maorių',
        'mn-MN'=> 'Mongolų',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norvegų bukmolas',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persų',
        'pl-PL'=> 'Lenkų',
        'pt-PT'=> 'Portugalų',
        'pt-BR'=> 'Portugalų, brazilų',
        'ro-RO'=> 'Rumunų',
        'ru-RU'=> 'Rusų',
        'sr-CS' => 'Serbų (lotynų)',
        'sk-SK'=> 'Slovakų',
        'sl-SI'=> 'Slovėnų',
        'so-SO'=> 'Somalių',
        'es-ES'=> 'Ispanų',
        'es-CO'=> 'Ispanų, Kolumbija',
        'es-MX'=> 'Ispanų, Meksika',
        'es-VE'=> 'Ispanų, Venesuela',
        'sv-SE'=> 'Švedų',
        'tl-PH'=> 'Tagalogų',
        'ta-IN'=> 'Tamilų',
        'th-TH'=> 'Tailandiečių',
        'tr-TR'=> 'Turkų',
        'uk-UA'=> 'Ukrainiečių',
        'vi-VN'=> 'Vietnamiečių',
        'cy-GB'=> 'Valų',
        'zu-ZA'=> 'Zulų',
    ],

    'select_country' => 'Pasirinkite šalį',
    
    'countries' => [
        'AC'=>'Dangun Žengimo sala',
        'AD'=>'Andora',
        'AE'=>'Jungtiniai Arabų Emyratai',
        'AF'=>'Afganistanas',
        'AG'=>'Antigva ir Barbuda',
        'AI'=>'Angilija',
        'AL'=>'Albanija',
        'AM'=>'Armėnija',
        'AN'=>'Nyderlandų Antilai',
        'AO'=>'Angola',
        'AQ'=>'Antarktida',
        'AR'=>'Argentina',
        'AS'=>'Amerikos Samoa',
        'AT'=>'Austrija',
        'AU'=>'Australija',
        'AW'=>'Aruba',
        'AX'=>'Alandai',
        'AZ'=>'Azerbaidžanas',
        'BA'=>'Bosnija ir Hercogovina',
        'BB'=>'Barbadosas',
        'BE'=>'Belgija',
        'BD'=>'Bangladešas',
        'BF'=>'Burkina Fasas',
        'BG'=>'Bulgarija',
        'BH'=>'Bahreinas',
        'BI'=>'Burundis',
        'BJ'=>'Beninas',
        'BM'=>'Bermudai',
        'BN'=>'Brunėjaus Valstybės Darusalamas',
        'BO'=>'Bolivija',
        'BR'=>'Brazilija',
        'BS'=>'Bahamos',
        'BT'=>'Butanas',
        'BV'=>'Buvė sala',
        'BW'=>'Botsvana',
        'BY'=>'Baltarusija',
        'BZ'=>'Belizas',
        'CA'=>'Kanada',
        'CC'=>'Kokosų (Kilingo) salos',
        'CD'=>'Kongo Demokratinė Respublika',
        'CF'=>'Centrinės Afrikos Respublika',
        'CG'=>'Kongo Respublika',
        'CH'=>'Šveicarija',
        'CI'=>'Dramblio Kaulo Krantas',
        'CK'=>'Kuko salos',
        'CL'=>'Čilė',
        'CM'=>'Kamerūnas',
        'CN'=>'Kinija',
        'CO'=>'Kolumbija',
        'CR'=>'Kosta Rika',
        'CU'=>'Kuba',
        'CV'=>'Žaliasis Kyšulys',
        'CX'=>'Kalėdų sala',
        'CY'=>'Kipras',
        'CZ'=>'Čekija',
        'DE'=>'Vokietija',
        'DJ'=>'Džibutis',
        'DK'=>'Danija',
        'DM'=>'Dominika',
        'DO'=>'Dominikos Respublika',
        'DZ'=>'Alžyras',
        'EC'=>'Ekvadoras',
        'EE'=>'Estija',
        'EG'=>'Egiptas',
        'GB-ENG'=>'Anglija',
        'ER'=>'Eritrėja',
        'ES'=>'Ispanija',
        'ET'=>'Etiopija',
        'EU'=>'Europos Sąjunga',
        'FI'=>'Suomija',
        'FJ'=>'Fidžis',
        'FK'=>'Folklando (Malvinų) salos',
        'FM'=>'Mikronezijos Federacinės Valstijos',
        'FO'=>'Farerai',
        'FR'=>'Prancūzija',
        'GA'=>'Gabonas',
        'GD'=>'Grenada',
        'GE'=>'Sakartvelas',
        'GF'=>'Prancūzijos Gviana',
        'GG'=>'Gernsis',
        'GH'=>'Gana',
        'GI'=>'Gibraltaras',
        'GL'=>'Grenlandija',
        'GM'=>'Gambija',
        'GN'=>'Gvinėja',
        'GP'=>'Gvadelupa',
        'GQ'=>'Pusiaujo Gvinėja',
        'GR'=>'Graikija',
        'GS'=>'Pietų Džordžijos ir Pietų Sandvičo salos',
        'GT'=>'Gvatemala',
        'GU'=>'Guamas',
        'GW'=>'Bisau Gvinėja',
        'GY'=>'Gajana',
        'HK'=>'Honkongas',
        'HM'=>'Herdo ir Makdonaldo salos',
        'HN'=>'Hondūras',
        'HR'=>'Kroatija',
        'HT'=>'Haitis',
        'HU'=>'Vengrija',
        'ID'=>'Indonezija',
        'IE'=>'Airija',
        'IL'=>'Izraelis',
        'IM'=>'Meno sala',
        'IN'=>'Indija',
        'IO'=>'Indijos Vandenyno Britų Sritis',
        'IQ'=>'Irakas',
        'IR'=>'Iranas',
        'IS'=>'Islandija',
        'IT'=>'Italija',
        'JE'=>'Džersis',
        'JM'=>'Jamaika',
        'JO'=>'Jordanija',
        'JP'=>'Japonija',
        'KE'=>'Kenija',
        'KG'=>'Kirgizija',
        'KH'=>'Kambodža',
        'KI'=>'Kiribatis',
        'KM'=>'Komorai',
        'KN'=>'Sent Kitsas ir Nevis',
        'KR'=>'Korėja',
        'KW'=>'Kuveitas',
        'KY'=>'Kaimanų salos',
        'KZ'=>'Kazachstanas',
        'LA'=>'Laosas',
        'LB'=>'Libanas',
        'LC'=>'Sent Lusija',
        'LI'=>'Lichtenšteinas',
        'LK'=>'Šri Lanka',
        'LR'=>'Liberija',
        'LS'=>'Lesotas',
        'LT'=>'Lietuva',
        'LU'=>'Liuksemburgas',
        'LV'=>'Latvija',
        'LY'=>'Libija',
        'MA'=>'Marokas',
        'MC'=>'Monakas',
        'MD'=>'Moldova',
        'ME'=>'Juodkalnija',
        'MG'=>'Madagaskaras',
        'MH'=>'Maršalo salos',
        'MK'=>'Šiaurės Makedonija',
        'ML'=>'Malis',
        'MM'=>'Mianmaras',
        'MN'=>'Mongolija',
        'MO'=>'Makao',
        'MP'=>'Marianos Šiaurinės salos',
        'MQ'=>'Martinika',
        'MR'=>'Mauritanija',
        'MS'=>'Montseratas',
        'MT'=>'Malta',
        'MU'=>'Mauricijus',
        'MV'=>'Maldyvai',
        'MW'=>'Malavis',
        'MX'=>'Meksika',
        'MY'=>'Malaizija',
        'MZ'=>'Mozambikas',
        'NA'=>'Namibija',
        'NC'=>'Naujoji Kaledonija',
        'NE'=>'Nigeris',
        'NF'=>'Norfolko sala',
        'NG'=>'Nigerija',
        'NI'=>'Nikaragva',
        'NL'=>'Nyderlandai',
        'GB-NIR' => 'Šiaurės Airija',
        'NO'=>'Norvegija',
        'NP'=>'Nepalas',
        'NR'=>'Nauru',
        'NU'=>'Niujė',
        'NZ'=>'Naujoji Zelandija',
        'OM'=>'Omanas',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Prancūzijos Polinezija',
        'PG'=>'Papua Naujoji Gvinėja',
        'PH'=>'Filipinai',
        'PK'=>'Pakistanas',
        'PL'=>'Lenkija',
        'PM'=>'Sen Pjeras ir Mikelonas',
        'PN'=>'Pitkerno salos',
        'PR'=>'Puerto Rikas',
        'PS'=>'Palestina',
        'PT'=>'Portugalija',
        'PW'=>'Palau',
        'PY'=>'Paragvajus',
        'QA'=>'Kataras',
        'RE'=>'Reunjonas',
        'RO'=>'Rumunija',
        'RS'=>'Serbija',
        'RU'=>'Rusija',
        'RW'=>'Ruanda',
        'SA'=>'Saudo Arabija',
        'GB-SCT'=>'Škotija',
        'SB'=>'Saliamono salos',
        'SC'=>'Seišeliai',
        'SS'=>'Pietų Sudanas',
        'SD'=>'Sudanas',
        'SE'=>'Švedija',
        'SG'=>'Singapūras',
        'SH'=>'Šv. Elenos sala',
        'SI'=>'Slovėnija',
        'SJ'=>'Svaldbardo ir Jan Majeno salos',
        'SK'=>'Slovakija',
        'SL'=>'Siera Leonė',
        'SM'=>'San Marinas',
        'SN'=>'Senegalas',
        'SO'=>'Somalis',
        'SR'=>'Surinamas',
        'ST'=>'San Tomė ir Prinsipė',
        'SU'=>'Sovietų Sąjunga',
        'SV'=>'Salvadoras',
        'SY'=>'Sirija',
        'SZ'=>'Svazilandas',
        'TC'=>'Terksas ir Kaikosas',
        'TD'=>'Čadas',
        'TF'=>'Prancūzijos Pietų Sritys',
        'TG'=>'Togas',
        'TH'=>'Tailandas',
        'TJ'=>'Tadžikija',
        'TK'=>'Tokelau',
        'TI'=>'Rytų Timoras',
        'TM'=>'Turkmėnija',
        'TN'=>'Tunisas',
        'TO'=>'Tonga',
        'TP'=>'Rytų Timoras (senas kodas)',
        'TR'=>'Turkija',
        'TT'=>'Trinidadas ir Tobagas',
        'TV'=>'Tuvalu',
        'TW'=>'Taivanas',
        'TZ'=>'Tanzanija',
        'UA'=>'Ukraina',
        'UG'=>'Uganda',
        'UK'=>'Jungtinė Karalystė',
        'US'=>'Jungtinės Amerikos Valstijos',
        'UM'=>'Jungtinių Valstijų mažosios tolimosios salos',
        'UY'=>'Urugvajus',
        'UZ'=>'Uzbekistanas',
        'VA'=>'Vatikanas',
        'VC'=>'Sent Vinsentas ir Grenadinai',
        'VE'=>'Venesuela',
        'VG'=>'Mergelių salos (Didžioji Britanija)',
        'VI'=>'Mergelių salos (JAV)',
        'VN'=>'Vietnamas',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Velsas',
        'WF'=>'Voliso ir Futūnos salos',
        'WS'=>'Samoa',
        'YE'=>'Jemenas',
        'YT'=>'Majotas',
        'ZA'=>'Pietų Afrika',
        'ZM'=>'Zambija',
        'ZW'=>'Zimbabvė',
    ],
];
